@@ -4,7 +4,7 @@
   Copyright (c) 2003,2004 Cornelius Schumacher <schumacher@kde.org>
   Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
   Copyright (C) 2009 Sebastian Sauer <sebsauer@kdab.net>
-  Copyright (c) 2010-2019 Laurent Montel <montel@kde.org>
+  Copyright (c) 2010-2020 Laurent Montel <montel@kde.org>
   Copyright (C) 2012 Sérgio Martins <iamsergio@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
@@ -304,6 +304,13 @@ public:
                 }
                 return font;
             }
+        } else if (role == Qt::DisplayRole) {
+            const Akonadi::Collection collection = CalendarSupport::collectionFromIndex(index);
+            const Akonadi::Collection::Id colId = collection.id();
+
+            if (colId == CalendarSupport::KCalPrefs::instance()->defaultCalendarId()) {
+                return i18nc("this is the default calendar", "%1 (Default Calendar)", collection.displayName());
+            }
         }
 
         return QSortFilterProxyModel::data(index, role);
@@ -573,7 +580,7 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
         connect(mAssignColor, &QAction::triggered, this, &AkonadiCollectionView::assignColor);
 
         mDefaultCalendar = new QAction(mCollectionView);
-        mDefaultCalendar->setText(i18n("Use as &Default Calendar"));
+        mDefaultCalendar->setText(i18n("Set as &Default Calendar"));
         mDefaultCalendar->setEnabled(false);
         xmlclient->actionCollection()->addAction(QStringLiteral("set_standard_calendar"),
                                                  mDefaultCalendar);
@@ -634,6 +641,19 @@ void AkonadiCollectionView::setDefaultCalendar()
     QModelIndex index = mCollectionView->selectionModel()->currentIndex(); //selectedRows()
     Q_ASSERT(index.isValid());
     const Akonadi::Collection collection = CalendarSupport::collectionFromIndex(index);
+
+    // Ask if they really want to do this
+    const Akonadi::Collection curCol(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
+    if (curCol.isValid() &&
+        KMessageBox::warningContinueCancel(
+            this,
+            i18nc("@info",
+                  "Do you really want replace your current default calendar with \"%1\"?",
+                   collection.displayName()),
+            i18nc("@title:window", "Replace Default Calendar?")) != KMessageBox::Continue) {
+              return;
+    }
+
     CalendarSupport::KCalPrefs::instance()->setDefaultCalendarId(collection.id());
     CalendarSupport::KCalPrefs::instance()->usrSave();
     updateMenu();
@@ -730,9 +750,11 @@ void AkonadiCollectionView::updateMenu()
             }
 
             mDisableColor->setEnabled(enableAction);
-            mDefaultCalendar->setEnabled(!KOHelper::isStandardCalendar(collection.id())
-                                         && collection.rights()
-                                         & Akonadi::Collection::CanCreateItem);
+            mDefaultCalendar->setEnabled(
+                !KOHelper::isStandardCalendar(collection.id()) &&
+                (collection.rights() & Akonadi::Collection::CanCreateItem) &&
+                !collection.isVirtual() &&
+                collection.contentMimeTypes().contains(KCalendarCore::Event::eventMimeType()));
             disableStuff = false;
         }
         bool isOnline;
@@ -751,7 +773,7 @@ void AkonadiCollectionView::updateMenu()
 void AkonadiCollectionView::newCalendar()
 {
     QPointer<Akonadi::AgentTypeDialog> dlg = new Akonadi::AgentTypeDialog(this);
-    dlg->setWindowTitle(i18n("Add Calendar"));
+    dlg->setWindowTitle(i18nc("@title:window", "Add Calendar"));
     dlg->agentFilterProxyModel()->addMimeTypeFilter(QStringLiteral("text/calendar"));
     dlg->agentFilterProxyModel()->addCapabilityFilter(QStringLiteral("Resource"));   // show only resources, no agents
     if (dlg->exec()) {
