@@ -102,7 +102,9 @@ void KODialogManager::showOptionsDialog()
         modules.append(QStringLiteral("korganizer_configfreebusy.desktop"));
         modules.append(QStringLiteral("korganizer_configplugins.desktop"));
         modules.append(QStringLiteral("korganizer_configdesignerfields.desktop"));
-
+#ifdef WITH_KUSERFEEDBACK
+        modules.append(QStringLiteral("korganizer_userfeedback.desktop"));
+#endif
         // add them all
         const QStringList::iterator mitEnd(modules.end());
         for (QStringList::iterator mit = modules.begin(); mit != mitEnd; ++mit) {
@@ -125,8 +127,8 @@ void KODialogManager::showSearchDialog()
     if (!mSearchDialog) {
         mSearchDialog = new SearchDialog(mMainView);
         //mSearchDialog->setCalendar( mMainView->calendar() );
-        connect(mSearchDialog, &SearchDialog::showIncidenceSignal, mMainView,
-                qOverload<>(&CalendarView::showIncidence));
+        connect(mSearchDialog, SIGNAL(showIncidenceSignal(Akonadi::Item)), mMainView,
+                SLOT(showIncidence(Akonadi::Item)));
         connect(mSearchDialog, SIGNAL(editIncidenceSignal(Akonadi::Item)), mMainView,
                 SLOT(editIncidence(Akonadi::Item)));
         connect(mSearchDialog, SIGNAL(deleteIncidenceSignal(Akonadi::Item)), mMainView,
